import { createApi } from "@reduxjs/toolkit/query/react";
import { baseQueryWithErrorHandling } from "core/helper/api";
import {
  Lesson,
  LessonPreview,
  UpdateLessonPreviewThumbnail,
} from "core/types/lesson";
import { LessonContent } from "features/Lessons/LessonPage";

export const lessonsApi = createApi({
  reducerPath: "lessonsApi",
  baseQuery: baseQueryWithErrorHandling,
  endpoints: (builder) => ({
    getLessons: builder.query<Lesson[], undefined>({
      query: () => ({
        url: "lessons",
        method: "GET",
      }),
    }),
    createLesson: builder.mutation({
      query: () => ({
        url: "lessons",
        method: "POST",
      }),
    }),
    getLessonPreview: builder.query<LessonPreview, string>({
      query: (lessonId) => ({
        url: `lessons/${lessonId}/preview`,
        method: "GET",
      }),
    }),
    getLessonContents: builder.query<LessonContent[], string>({
      query: (lessonId) => ({
        url: `lessons/${lessonId}/contents`,
        method: "GET",
      }),
    }),
    updateLessonPreviewTitle: builder.mutation({
      query: ({ lessonId, newTitle }) => ({
        url: `lessons/${lessonId}/preview/title`,
        method: "PATCH",
        body: { Title: newTitle },
      }),
    }),
    updateLessonPreviewThumbnail: builder.mutation<
      void,
      UpdateLessonPreviewThumbnail
    >({
      query: ({ lessonId, formData }) => ({
        url: `lessons/${lessonId}/preview/thumbnail`,
        method: "PATCH",
        body: formData,
      }),
    }),
  }),
});

export const {
  useGetLessonsQuery,
  useCreateLessonMutation,
  useGetLessonPreviewQuery,
  useGetLessonContentsQuery,
  useUpdateLessonPreviewTitleMutation,
  useUpdateLessonPreviewThumbnailMutation,
} = lessonsApi;
