import { DndContext, DragEndEvent, useDroppable } from "@dnd-kit/core";
import { verticalListSortingStrategy, SortableContext } from "@dnd-kit/sortable";
import SortableEditorItem from "./SortableEditorItem";
import React from "react";
import { LessonContent } from "../LessonPage";
import { store } from "core/store/store";

import {
  restrictToVerticalAxis,
  restrictToWindowEdges,
} from "@dnd-kit/modifiers";
import { lessonContents, onDragHandler } from "./lessonPageEditorSlice";

const Droppable = ({ items }: { items: LessonContent[] }) => {
  const droppableID = "editorComponentArea";
  const { setNodeRef } = useDroppable({ id: droppableID });
 

  const itemIDs = items.map((item) => item.id);

  return (
    <DndContext modifiers={[restrictToVerticalAxis, restrictToWindowEdges]} onDragEnd={handleDragEnd}>
      <SortableContext
        id={droppableID}
        items={itemIDs}
        strategy={verticalListSortingStrategy}
      >
        <div ref={setNodeRef}  >
          {items.map((item) => (
            <SortableEditorItem key={`${droppableID}_${item.id}`} item={item} />
          ))}
        </div>
      </SortableContext>
    </DndContext>
  );
};

function handleDragEnd(event: DragEndEvent) {
  console.log("drag end",event); 

  if(!event.over) return;

  const activeId = event.active.id;
  const overId = event.over.id;


 
  store.dispatch(onDragHandler({activeId, overId})); 
}


export default Droppable;
