import React from "react";
import { defaultAnimateLayoutChanges, useSortable } from "@dnd-kit/sortable";
import { CSS } from "@dnd-kit/utilities";
import { Converter, LessonContent } from "../LessonPage";
import { HolderOutlined, DeleteOutlined } from "@ant-design/icons";
import { Flex } from "antd";
import { setLessonContent, deleteLessonContent } from "./lessonPageEditorSlice";
import { useDispatch } from "react-redux";

const animateLayoutChanges = (args: any) =>
  args.isSorting || args.wasDragging ? defaultAnimateLayoutChanges(args) : true;

const SortableEditorItem = (props: {item:LessonContent}) => {
  const lnContent = props.item;
  const {
    attributes,
    listeners,
    setNodeRef,
    transform,
    transition
  } = useSortable({ id: lnContent.id, animateLayoutChanges });

  const dispatch = useDispatch();
 

  return (
    <div style={{
        transform: CSS.Translate.toString(transform),
        transition
      }} ref={setNodeRef} {...attributes} >
        <Flex key={lnContent.id} >
            <HolderOutlined style={{paddingLeft:8,paddingRight:8, touchAction: "none", cursor: "move"}}{...listeners}/>
            <Converter
              mode="edititable"
              lessonContent={lnContent}
              onEdit={(data) =>
                dispatch(
                  setLessonContent({
                    id: lnContent.id,
                    data: data,
                  })
                )
              }
            />

            <DeleteOutlined
              onClick={() => {
                console.log("delete", lnContent.id);
                dispatch(deleteLessonContent(lnContent.id));
              }}
            />
        </Flex>
    </div>
  );
};

export default SortableEditorItem;
