import { createSlice } from "@reduxjs/toolkit";
import { LessonContent } from "../LessonPage";
import { StandardEditorCompontent } from ".";

export const lessonPageEditorSlice = createSlice({
  name: "lessonPageEditor",
  initialState: {
    editorActive: false,
    lessonThumbnail: {
      img: "",
      title: "Test",
    },
    lessonContents: [] as LessonContent[],
  },
  reducers: {
    setEditorActive: (state, action) => {
      state.editorActive = action.payload;
    },
    addLessonContent: (state, action) => {
      state.lessonContents.push(StandardEditorCompontent(action.payload));
    },
    deleteLessonContent: (state, action) => {
      state.lessonContents = state.lessonContents.filter(
        (content) => content.id !== action.payload
      );
    },
    setLessonContent: (state, action) => {
      const index = state.lessonContents.findIndex(
        (content) => content.id === action.payload.id
      );

      state.lessonContents[index].data = action.payload.data;
    },
    setLessonThumbnailTitle: (state, action) => {
      state.lessonThumbnail.title = action.payload;
    },
    onDragHandler: (state, action) => {
      const { activeId, overId } = action.payload as {
        activeId: string;
        overId: string;
      };

      if (activeId !== overId) {
        let oldIndex = state.lessonContents.findIndex(
          (item) => item.id === activeId
        );
        let newIndex = state.lessonContents.findIndex(
          (item) => item.id === overId
        );

        state.lessonContents.splice(
          newIndex,
          0,
          state.lessonContents.splice(oldIndex, 1)[0]
        );
      }
    },
  },
  selectors: {
    editorActive: (state) => state.editorActive,
    lessonContents: (state) => state.lessonContents,
    lessonThumbnail: (state) => state.lessonThumbnail,
  },
});

export const {
  setEditorActive,
  addLessonContent,
  deleteLessonContent,
  setLessonContent,
  setLessonThumbnailTitle,
  onDragHandler,
} = lessonPageEditorSlice.actions;

export const { editorActive, lessonContents, lessonThumbnail } =
  lessonPageEditorSlice.selectors;
